@@ -41,7 +41,7 @@ gghead <- ggplot(Orange, aes(age, circumference, color = Tree))
 gghead +
   gg_ls
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 data.frame(
   object = c("head", "body", "render"),
   ggplot2 = c("ggplot()", "geom_*()", "NA"),
@@ -50,7 +50,7 @@ data.frame(
 ) %>%
   knitr::kable()
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  library(tourr)
 #  library(spinifex)
 #  
@@ -61,7 +61,7 @@ data.frame(
 #  
 #  ## Manual tour, manipulating the contribution of a selected variable
 #  bas     <- basis_pca(dat)    ## Start basis
-#  mv      <- manip_var_of(bas) ## Number of the variable to manipulate
+#  mv      <- 1 ## Number of the variable to manipulate
 #  mt_path <- manual_tour(bas, manip_var = mv) ## Tour path
 #  
 #  ## Create a static ggplot2 plot with all frames of the tour
@@ -75,7 +75,7 @@ data.frame(
 #  ## Or as a plotly html widget
 #  #animate_plotly(ggt)
 
-## ---- echo=FALSE, out.width="100%"--------------------------------------------
+## ----echo=FALSE, out.width="100%"---------------------------------------------
 ## Cut down sub-directory size, making animations to gif and including those.
 if(FALSE){
   library(tourr)
@@ -83,7 +83,7 @@ if(FALSE){
   dat  <- scale_sd(penguins_na.rm[, 1:4])
   clas <- penguins_na.rm$species
   bas     <- basis_pca(dat)    ## Start basis
-  mv      <- manip_var_of(bas) ## Number of the variable to manipulate
+  mv      <- 1 ## Number of the variable to manipulate
   mt_path <- manual_tour(bas, manip_var = mv) ## Tour path
   ggt <- ggtour(mt_path, dat, angle = .2) +
     proto_basis() +
@@ -92,9 +92,10 @@ if(FALSE){
   anim <- animate_gganimate(ggt, height = 3, width = 4.5, units = "in", res = 150)
   gganimate::anim_save("proto_mt_penguins.gif", animation = anim, path = "./vignettes")
 }
-knitr::include_graphics("./proto_mt_penguins.gif")
+#knitr::include_graphics("./proto_mt_penguins.gif")
+#knitr::include_url("https://github.com/nspyrison/spinifex/blob/master/vignettes/proto_mt_penguins.gif?raw=true")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ## Save a grand tour basis path, projecting through randomly selected bases
 #  gt_path <- save_history(dat, grand_tour(), max_bases = 3)
 #  
@@ -109,7 +110,7 @@ knitr::include_graphics("./proto_mt_penguins.gif")
 #  ## Or as a plotly html widget
 #  #animate_plotly(ggt)
 
-## ---- echo=FALSE, out.width="100%"--------------------------------------------
+## ----echo=FALSE, out.width="100%"---------------------------------------------
 ## Cut down sub-directory size, making animations to gif and including those.
 if(FALSE){
   gt_path <- save_history(dat, grand_tour(), max_bases = 3)
@@ -119,9 +120,10 @@ if(FALSE){
   anim <- animate_gganimate(ggt, height = 2, width = 4.5, units = "in", res = 150)
   gganimate::anim_save("proto_gt_penguins.gif", animation = anim, path = "./vignettes")
 }
-knitr::include_graphics("./proto_gt_penguins.gif")
+#knitr::include_graphics("./proto_gt_penguins.gif")
+#knitr::include_url("https://github.com/nspyrison/spinifex/blob/master/vignettes/proto_guided1d_penguins.gif?raw=true")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ## (Quietly create) a 1d guided tour, optimizing the projection space for the holes() function
 #  guided_path <- save_history(dat, guided_tour(holes(), d = 1))
 #  
@@ -135,7 +137,7 @@ knitr::include_graphics("./proto_gt_penguins.gif")
 #  ## Or as a plotly html widget
 #  #animate_plotly(ggt)
 
-## ---- echo=FALSE, out.width="100%"--------------------------------------------
+## ----echo=FALSE, out.width="100%"---------------------------------------------
 ## Cut down sub-directory size, making animations to gif and including those.
 if(FALSE){
   guided_path <- save_history(dat, guided_tour(holes(), d = 1))
@@ -146,72 +148,69 @@ if(FALSE){
   gganimate::anim_save(
     "proto_guided1d_penguins.gif", animation = anim, path = "./vignettes")
 }
-knitr::include_graphics("./proto_guided1d_penguins.gif")
+#knitr::include_graphics("./proto_guided1d_penguins.gif")
+#knitr::include_url("https://github.com/nspyrison/spinifex/blob/master/vignettes/proto_guided1d_penguins.gif?raw=true")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ggt <- ggt +
 #    theme_bw() +
-#    ggtitle("My Tour animation") +
-#    labs(x = "Projection Y1", y = "density")
+#    ggtitle("My Tour Animation") +
+#    labs(x = "Y1", y = "Density")
 #  
-#  animate_gganimate(ggt, height = 2, width = 4.5, units = "in", res = 150)
+#  animate_gganimate(ggt, height = 2, width = 3, units = "in", res = 150)
 #  ## Or as a plotly html widget
 #  #animate_plotly(ggt)
 
-## ---- echo=FALSE, out.width="100%"--------------------------------------------
+## ----echo=FALSE, out.width="100%"---------------------------------------------
 ## Cut down sub-directory size, making animations to gif and including those.
 if(FALSE){
   ggt <- ggt +
     theme_bw() +
     ggtitle("My Tour animation") +
-    labs(x = "Projection Y1", y = "density")
+    labs(x = "Y1", y = "density")
   
-  anim <- animate_gganimate(ggt, height = 2, width = 4.5, units = "in", res = 150)
+  anim <- animate_gganimate(ggt, height = 4, width = 4, units = "in", res = 150)
   gganimate::anim_save(
     "proto_guided1d_interop_penguins.gif", animation = anim, path = "./vignettes")
 }
-knitr::include_graphics("./proto_guided1d_interop_penguins.gif")
+#knitr::include_graphics("./proto_guided1d_interop_penguins.gif")
+#knitr::include_url("https://github.com/nspyrison/spinifex/blob/master/vignettes/proto_guided1d_interop_penguins.gif?raw=true")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  dat     <- scale_sd(PimaIndiansDiabetes_wide[, -9])
-#  clas    <- PimaIndiansDiabetes_wide$diabetes
+## ----eval=FALSE---------------------------------------------------------------
 #  gt_path <- save_history(dat, max = 7)
-#  
 #  ggt <- ggtour(gt_path, dat, angle = .3) +
 #    facet_wrap_tour(facet_var = clas, nrow = 1) +
 #    proto_point(list(color = clas, shape = clas)) +
 #    proto_basis(position = "center") +
 #    proto_origin()
 #  
-#  animate_gganimate(ggt, height = 2, width = 4.5, units = "in", res = 150)
+#  animate_gganimate(ggt, height = 2, width = 6, units = "in", res = 150)
 #  ## Or as a plotly html widget
 #  #animate_plotly(ggt)
 
-## ---- echo=FALSE, out.width="100%"--------------------------------------------
+## ----echo=FALSE, out.width="100%"---------------------------------------------
 ## Cut down sub-directory size, making animations to gif and including those.
 if(FALSE){
-  dat     <- scale_sd(PimaIndiansDiabetes_wide[, -9])
-  clas    <- PimaIndiansDiabetes_wide$diabetes
   gt_path <- save_history(dat, max = 7)
   ggt     <- ggtour(gt_path, dat, angle = .3) +
     facet_wrap_tour(facet_var = clas, nrow = 1) +
     proto_point(list(color = clas, shape = clas)) +
     proto_basis(position = "center") +
     proto_origin()
-  anim <- animate_gganimate(ggt, height = 2, width = 4.5, units = "in", res = 150)
+  anim <- animate_gganimate(ggt, height = 2, width = 6, units = "in", res = 150)
   gganimate::anim_save(
     "proto_facet_penguins.gif", animation = anim, path = "./vignettes")
 }
-knitr::include_graphics("./proto_facet_penguins.gif")
+#knitr::include_graphics("./proto_facet_penguins.gif")
+#knitr::include_url("https://github.com/nspyrison/spinifex/blob/master/vignettes/proto_facet_penguins.gif?raw=true")
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 data.frame(
   `proto functions` =
     c("ggtour", "proto_point", "proto_text", "proto_hex", "proto_origin/1d", "proto_density", "proto_basis/1d", "proto_default/1d", "animate_plotly", "animate_gganimate"),
   `related ggplot2 function` =
     c("ggplot", "geom_point", "geom_text", "geom_hex", "NA", "geom- _density & _rect", "geom- _segment & _text", "several protos", "plotly::ggplotly (with animation)", "gganimate::animate"),
   detail =
-    c("Also perfroms setup for the tour.", "-", "-", "Heatmap hexegons, for high observation density", "Line segments for the origin, the space where 0 values project to", "1D density with run hash marks underneath, `position = 'stack'` not working with plotly.", "html widget, row numbers added as tooltip on hover. plotly doesn't presicly map all ggplot2 settings; legends, point size and opacity may vary.", "Direction and magnetude of variables to the projection disp~", "Default protos for 2/1D tours", "gif, mp4 and other video animation. gganimate consumes native ggplots and aestheics should be consistant."), check.names = F
-) %>%
+    c("Also perfroms setup for the tour.", "-", "-", "Heatmap hexegons, for high observation density", "Line segments for the origin, the space where 0 values project to", "1D density with run hash marks underneath, `position = 'stack'` not working with plotly.", "html widget, row numbers added as tooltip on hover. plotly doesn't presicly map all ggplot2 settings; legends, point size and opacity may vary.", "Direction and magnetude of variables to the projection disp~", "Default protos for 2/1D tours", "gif, mp4 and other video animation. gganimate consumes native ggplots and aestheics should be consistant."), check.names = F) %>%
   knitr::kable()
 
